Library

Struct Library 

pub struct Library {
    pub module: Module,
    pub exports: Interface,
    pub imports: Vec<Interface>,
}

Fields

module: Moduleexports: Interfaceimports: Vec<Interface>

Implementations

Source

impl Library

pub fn interface_name(&self) -> &str

The name of the interface being generated.

If coming from a WIT file, this will be the wasmer-pack in wasmer-pack.exports.wit.

pub fn class_name(&self) -> String

The name of the class generated by wai-bindgen.

For example, if you were generating bindings for wasmer-pack.exports.wit, this would be WasmerPack.

pub fn module_filename(&self) -> &str

The filename of the Module this Library contains.

For example, if the Module was loaded from ./path/to/wasmer-pack.wasm, this would be wasmer-pack.wasm.

pub fn requires_wasi(&self) -> bool