Module

Struct Module 

pub struct Module {
    pub name: String,
    pub abi: Abi,
    pub wasm: Vec<u8>,
}
A WebAssembly module.

Fields

name: String

A name used to refer to this module (e.g. wasmer_pack_wasm).

abi: Abi

The ABI used by the module.

wasm: Vec<u8>

The WebAssembly code, itself.

Implementations

Source

impl Module

pub fn from_path(path: impl AsRef<Path>, abi: Abi) -> Result<Self, Error>

Load a Module from a file on disk.

Note

The Module::from_path() constructor explicitly doesn’t perform any validation on the module’s file. It is up to the caller to ensure they pass in the correct Abi.