PackageName

Struct PackageName 

pub struct PackageName { /* private fields */ }
The name of a package from WAPM (e.g. wasmer/wasmer-pack).

Syntax:

  • A PackageName consists of a “name” and an optional “namespace or username”
  • The “namespace or username” may be an “identifier” or the “_” namespace (used for backwards compatibility)
  • If a “namespace or username” isn’t provided, it is assumed to be a package alias and will be resolved to a package by the WAPM backend
  • “Identifiers” can only contain alphanumeric ascii characters, _, and -
  • “Identifiers” must also start with an ascii character and be at most 100 characters long

Implementations

Source

impl PackageName

pub fn parse(raw: &str) -> Result<Self, Error>

pub fn name(&self) -> &str

pub fn namespace(&self) -> &Namespace

pub fn javascript_package(&self) -> String

Get the NPM equivalent of this PackageName.

This should satisfy NPM’s naming rules:

  • package name length should be greater than zero
  • all the characters in the package name must be lowercase i.e., no uppercase or mixed case names are allowed
  • package name can consist of hyphens
  • package name must not contain any non-url-safe characters (since name ends up being part of a URL)
  • package name should not start with . or _
  • package name should not contain any spaces
  • package name should not contain any of the following characters: ~)(’!*
  • package name cannot be the same as a node.js/io.js core module nor a reserved/blacklisted name. For example, the following names are invalid:
    • http
    • stream
    • node_modules
    • favicon.ico
  • package name length cannot exceed 214
pub fn python_name(&self) -> String

Get the PyPI equivalent of this PackageName.

This should satisfy the naming scheme outlined in PEP 8:

Modules should have short, all-lowercase names. Underscores can be used in the module name if it improves readability. Python packages should also have short, all-lowercase names, although the use of underscores is discouraged.